==> django-userena-ce-6.0.0.tar.gz: django-userena-ce-6.0.0/README.md <==
# Django Userena (Community Edition)

[![PyPI version](https://badge.fury.io/py/django-userena-ce.svg)](https://badge.fury.io/py/django-userena-ce)
[![Build Status](https://travis-ci.org/django-userena-ce/django-userena-ce.svg?branch=master)](https://travis-ci.org/django-userena-ce/django-userena-ce)
[![Coverage Status](https://coveralls.io/repos/github/django-userena-ce/django-userena-ce/badge.svg?branch=master)](https://coveralls.io/github/django-userena-ce/django-userena-ce?branch=master)
[![Documentation Status](https://readthedocs.org/projects/django-userena-ce/badge/?version=latest)](http://django-userena-ce.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/django-userena-ce/django-userena-ce/shield.svg)](https://pyup.io/repos/github/django-userena-ce/django-userena-ce/)

Due to a lack of maintainance this project is a community edition fork of
[django-userena](https://github.com/bread-and-pepper/django-userena).

Userena is a Django application that supplies your Django project with full
account management. It's a fully customizable application that takes care of
the signup, activation, messaging and more. It's BSD licensed, which means you
can use it commercially for free!

## Supported Software

Software | Versions
---|---
Python | 3.6, 3.7, 3.8
Django | 2.2, 3.0
Django Guardian | \>2.0

## [Documentation](https://django-userena-ce.readthedocs.io/en/latest/index.html)

Complete documentation about the
[installation](https://django-userena-ce.readthedocs.io/en/latest/installation.html),
[settings](https://django-userena-ce.readthedocs.io/en/latest/settings.html) and
[F.A.Q.](https://django-userena-ce.readthedocs.io/en/latest/faq.html) is available on
[Read the Docs](https://django-userena-ce.readthedocs.io/en/latest/index.html).

For list of updates and changes see `UPDATES.md` file.

==> django-userena-ce-7.0.0a1.tar.gz: django-userena-ce-7.0.0a1/README.md <==
# Django Userena (Community Edition)

[![Build Status](https://github.com/django-userena-ce/django-userena-ce/workflows/CI/badge.svg)](https://github.com/django-userena-ce/django-userena-ce/actions?query=workflow%3ACI+branch%3Amaster)
[![PyPI version](https://badge.fury.io/py/django-userena-ce.svg)](https://badge.fury.io/py/django-userena-ce)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-userena-ce)](https://pypi.org/project/django-userena-ce/)
[![Coverage Status](https://coveralls.io/repos/github/django-userena-ce/django-userena-ce/badge.svg?branch=master)](https://coveralls.io/github/django-userena-ce/django-userena-ce?branch=master)
[![Documentation Status](https://readthedocs.org/projects/django-userena-ce/badge/?version=latest)](http://django-userena-ce.readthedocs.io/en/latest/?badge=latest)

This project is a community edition fork of
[django-userena](https://github.com/bread-and-pepper/django-userena).

Userena is a Django application that supplies your Django project with full
account management. It's a fully customizable application that takes care of
the signup, activation, messaging and more. It's BSD licensed, which means you
can use it commercially for free!

## Supported Software

Software | Versions
---|---
Python | 3.7, 3.8, 3.9, 3.10
Django | 3.2, 4.0
Django Guardian | \>2.0

## [Documentation](https://django-userena-ce.readthedocs.io/en/latest/index.html)

Complete documentation about the
[installation](https://django-userena-ce.readthedocs.io/en/latest/installation.html),
[settings](https://django-userena-ce.readthedocs.io/en/latest/settings.html) and
[F.A.Q.](https://django-userena-ce.readthedocs.io/en/latest/faq.html) is available on
[Read the Docs](https://django-userena-ce.readthedocs.io/en/latest/index.html).

For list of updates and changes see `UPDATES.md` file.
